==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="1181"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1460"/>
        <source>Photo</source>
        <translation>Billede</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1469"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1901"/>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Videooptagning foregår. Lukk vinduet?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2034"/>
        <source>Switch Cameras</source>
        <translation>Skift kamera</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2128"/>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../src/closedialog.cpp" line="26"/>
        <source>Cancel</source>
        <translation>Annullér</translation>
    </message>
    <message>
        <location filename="../src/closedialog.cpp" line="26"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <location filename="../src/imageitem.cpp" line="66"/>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="70"/>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="74"/>
        <source>Open folder</source>
        <translation>Åbn mappe</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="77"/>
        <source>Print</source>
        <translation>Udskriv</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="213"/>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="229"/>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera er en værktøj til optagelse af billeder og video, der bruger dit PC-kamera eller webkamera.</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="16"/>
        <source>OptionPicLineEditBtn</source>
        <translation>OptionPicLineEditBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="17"/>
        <source>OptionVideoLineEditBtn</source>
        <translation>OptionVideoLineEditBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="18"/>
        <source>OptionFormatLabel</source>
        <translation>OptionFormatLabel</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="19"/>
        <source>OptionFrame</source>
        <translation>OptionFrame</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="20"/>
        <source>PicOption</source>
        <translation>PicOption</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="21"/>
        <source>VideoOption</source>
        <translation>VideoOption</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="22"/>
        <source>OptionPicSelectableLineEdit</source>
        <translation>OptionPicSelectableLineEdit</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="23"/>
        <source>OptionVideoSelectableLineEdit</source>
        <translation>OptionVideoSelectableLineEdit</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="24"/>
        <source>OptionInvalidDialog</source>
        <translation>OptionInvalidDialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="25"/>
        <source>SettingDialog</source>
        <translation>SettingDialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="27"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="28"/>
        <source>TitleBar</source>
        <translation>TitleBar</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="29"/>
        <source>TitleMenu</source>
        <translation>TitleMenu</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="30"/>
        <source>VideoPreviewWidget</source>
        <translation>VideoPreviewWidget</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="33"/>
        <source>SelectBtn</source>
        <translation>SelectBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="34"/>
        <source>PicVdBtn</source>
        <translation>PicVdBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="35"/>
        <source>TakeVdEndBtn</source>
        <translation>Tage video slut knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="36"/>
        <source>ThumbnailPreview</source>
        <translation>Miniaturprævisualisering</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="37"/>
        <source>ModeSwitchBox</source>
        <translation>Modusomskiftningsboks</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="38"/>
        <source>SwitchRecordBtn</source>
        <translation>Skift registreringsknap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="40"/>
        <source>LeftBtnsBox</source>
        <translation>Venstre knapboks</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="41"/>
        <source>UnfoldBtn</source>
        <translation>Udfold knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="42"/>
        <source>FoldBtn</source>
        <translation>Fold knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="43"/>
        <source>FlashlightUnfoldBtn</source>
        <translation>Lampe udfold knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="44"/>
        <source>FlashlightFoldBtn</source>
        <translation>Lampe fold knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="45"/>
        <source>FlashlightOnBtn</source>
        <translation>Lampe på knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="46"/>
        <source>FlashlightOffBtn</source>
        <translation>Lampe fra knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="47"/>
        <source>DelayUnfoldBtn</source>
        <translation>Forsinkelse udfold knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="48"/>
        <source>DelayFoldBtn</source>
        <translation>Forsinkelse fold knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="49"/>
        <source>DelayNoDelayBtn</source>
        <translation>Ingen forsinkelse knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="50"/>
        <source>Delay3SecBtn</source>
        <translation>3 sekunder forsinkelse knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="51"/>
        <source>Delay6SecBtn</source>
        <translation>6 sekunder forsinkelse knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="52"/>
        <source>FiltersUnfoldBtn</source>
        <translation>Filtre udfold knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="53"/>
        <source>FiltersFoldBtn</source>
        <translation>Filtre fold knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="54"/>
        <source>FiltersCloseBtn</source>
        <translation>Filtre luk knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="55"/>
        <source>ExposureBtn</source>
        <translation>Udholdenhed knap</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="56"/>
        <source>ExposureSlider</source>
        <translation>Udholdenheds skyder</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="59"/>
        <source>ShortcutCallMenu</source>
        <translation>Kortkommando ring menu</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="60"/>
        <source>ShortcutCopy</source>
        <translation>Kortkommando kopier</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="61"/>
        <source>ShortcutDelete</source>
        <translation>Kortkommando slet</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="62"/>
        <source>ShortcutOpenFolder</source>
        <translation>Kortkommando åbn mappe</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="63"/>
        <source>ShortcutPrint</source>
        <translation>Kortkommando print</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="66"/>
        <source>ViewShortCut</source>
        <translation>Vis kortkommando</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="67"/>
        <source>SpaceShortCut</source>
        <translation>Rum kortkommando</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="70"/>
        <source>CloseDlg</source>
        <translation>Luk dialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="73"/>
        <source>PrintDialog</source>
        <translation>Print dialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="76"/>
        <source>CancelBtn</source>
        <translation>Annullér</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="77"/>
        <source>CloseBtn</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="287"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Du har ikke tilladelse til at arbejde med denne mappe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="289"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="361"/>
        <source>Open folder</source>
        <translation>Åbn mappe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="909"/>
        <source>File not saved</source>
        <translation>Filen er ikke gemt</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="10"/>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="11"/>
        <source>Basic</source>
        <translation>Grundlæggende</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="12"/>
        <source>File location</source>
        <translation>Filplacering</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="13"/>
        <source>Photos:</source>
        <translation>Billeder:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="14"/>
        <source>Videos:</source>
        <translation>Videoer:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="15"/>
        <source>Gridlines</source>
        <translation>Ruter</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="16"/>
        <source>1*1 lines</source>
        <translation>1*1 linjer</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="17"/>
        <source>2*2 lines</source>
        <translation>2*2 linjer</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="18"/>
        <source>Shoot</source>
        <translation>Tage</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="19"/>
        <source>Burst mode</source>
        <translation>Burst-tilstand</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="20"/>
        <source>Self-timer delay</source>
        <translation>Selvtimerforsinkelse</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="21"/>
        <source>Mirror mode</source>
        <translation>Spejlingstilstand</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="22"/>
        <source>Flashlight</source>
        <translation>Tændstik</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="23"/>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="24"/>
        <source>Sound effects</source>
        <translation>Lydeffekter</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="25"/>
        <source>Output format</source>
        <translation>Outputformat</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="26"/>
        <source>Photo:</source>
        <translation>Billede:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="27"/>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="28"/>
        <source>4 pcs</source>
        <translation>4 stk</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="29"/>
        <source>10 pcs</source>
        <translation>10 stk</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="30"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="31"/>
        <source>Resolution settings</source>
        <translation>Oppløsningsindstillinger</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="32"/>
        <source>Maximum resolution:</source>
        <translation>Maksimal oppløsning:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../src/shortcut.cpp" line="14"/>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="15"/>
        <source>Settings</source>
        <translation>Instillinger</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="16"/>
        <source>Stop recording</source>
        <translation>Sluk optagelse</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="17"/>
        <source>Stop taking photos</source>
        <translation>Sluk for at tage billeder</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="18"/>
        <source>Context menu</source>
        <translation>Kontekstmenu</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="19"/>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="20"/>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="21"/>
        <source>Open</source>
        <translation>Åbn</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="22"/>
        <source>Print</source>
        <translation>Udskriv</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="23"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="24"/>
        <source>Display shortcuts</source>
        <translation>Vis genveje</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <location filename="../src/Settings.cpp" line="61"/>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <location filename="../src/Settings.cpp" line="61"/>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <location filename="../src/Settings.cpp" line="191"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="254"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="260"/>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="263"/>
        <source>Warm</source>
        <translation>Varm</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="266"/>
        <source>Cold</source>
        <translation>Kold</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="269"/>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="272"/>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="275"/>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="278"/>
        <source>B&amp;W</source>
        <translation>Svart og hvid</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="83"/>
        <source>Flashlight</source>
        <translation>Tændstik</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="90"/>
        <source>On</source>
        <translation>På</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="97"/>
        <source>Off</source>
        <translation>Fra</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="112"/>
        <source>Delay capture</source>
        <translation>Forsink optagelse</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="119"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="142"/>
        <source>Filters</source>
        <translation>Filtere</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="191"/>
        <source>Exposure</source>
        <translation>Ekspotering</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <location filename="../src/videowidget.cpp" line="346"/>
        <source>No webcam found</source>
        <translation>Ingen webcam fundet</translation>
    </message>
    <message>
        <location filename="../src/videowidget.cpp" line="384"/>
        <source>The webcam is in use</source>
        <translation>Webcamen er i brug</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.33.tar.xz: BUILD/src/translations/deepin-camera_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Videooptagelsen er i gang. Luk vinduet?</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Intet</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Skift kamera</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Afbryd</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Åben mappe</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Udskriv</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Du har ikke tilladelse til at arbejde med denne mappe</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Åben mappe</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Grundlæggende</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Filplacering</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Tag</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Burst-tilstand</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Selv-timerforsinkelse</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Outputformat</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 stk</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 stk</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Intet</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera er et værktøj til optagelse af billeder og video, der bruger dit PC-kamera eller webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Fil ikke gemt</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Opstillingsindstillinger</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Billeder:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Lydeffekter</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Spejlbælte</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Lampe</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Rætlinjer</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 linjer</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 linjer</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Maksimal oppløsning:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Stop med op­tage</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åben</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Udskriv</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Vis genkaldingsknapper</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Stop med at tage billeder</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontekstmenu</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Varm</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Kold</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Svart og hvid</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Lampe</translation>
    </message>
    <message>
        <source>On</source>
        <translation>På</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Fra</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Forsinket optagelse</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Ekspotering</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Ingen webkamera fundet</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Webkameraen er i brug</translation>
    </message>
</context>
</TS>
